@@ -1,4 +1,4 @@
-use rand_core::CryptoRngCore;
+use rand_core::{CryptoRng, CryptoRngCore, RngCore};
 
 #[cfg(feature = "default-rng")]
 use rand_core::OsRng;
@@ -10,17 +10,20 @@ pub trait KeyGen {
     type EncapsKey;
     /// The (private) decapsulation key used by the originator to generate the shared secret.
     type DecapsKey;
-    /// A serialized (public) encapsulation key byte array of the correct length
+    /// A serialized (public) encapsulation key byte array of the correct length.
     type EncapsByteArray;
-    /// A serialized (private) decapsulation key of the correct length
+    /// A serialized (private) decapsulation key byte array of the correct length.
     type DecapsByteArray;
 
 
-    /// Generates an encapsulation and decapsulation key pair specific to this security parameter set. <br>
-    /// This function utilizes the OS default random number generator and is intended to operate in constant
-    /// time outside of `rho` which crosses the trust boundary in the clear.
+    /// Generates an encapsulation and decapsulation key pair specific to this security parameter set.
+    ///
+    /// This function uses the OS default random number generator and operates in constant time,
+    /// except for the `rho` operation which crosses the trust boundary in the clear.
+    ///
     /// # Errors
-    /// Returns an error when the random number generator fails.
+    /// Returns an error if the random number generator fails.
+    ///
     /// # Examples
     /// ```rust
     /// # use std::error::Error;
@@ -53,11 +56,17 @@ pub trait KeyGen {
     }
 
 
-    /// Generates an encapsulation and decapsulation key key pair specific to this security parameter set. <br>
-    /// This function utilizes a provided random number generator and is intended to operate in constant
-    /// time outside of `rho` which crosses the trust boundary in the clear.
+    /// Generates an encapsulation and decapsulation key pair using a provided random number generator.
+    ///
+    /// This function operates in constant time, except for the `rho` operation which crosses
+    /// the trust boundary in the clear.
+    ///
+    /// # Arguments
+    /// * `rng` - A cryptographically secure random number generator implementing `CryptoRngCore`
+    ///
     /// # Errors
-    /// Returns an error when the random number generator fails.
+    /// Returns an error if the random number generator fails.
+    ///
     /// # Examples
     /// ```rust
     /// # use std::error::Error;
@@ -159,11 +168,12 @@ pub trait KeyGen {
 }
 
 
-/// The `Encaps` trait uses the encapsulation key to generate the ciphertext and shared secret.
+/// The `Encaps` trait defines methods for generating shared secrets and ciphertexts using
+/// an encapsulation key.
 pub trait Encaps {
-    /// The common shared secret
+    /// The shared secret key type generated during encapsulation
     type SharedSecretKey;
-    /// The ciphertext transmitted from the remote party to the originator.
+    /// The ciphertext type transmitted from the encapsulating party to the decapsulating party
     type CipherText;
 
 
@@ -240,21 +250,79 @@ pub trait Encaps {
     fn try_encaps_with_rng(
         &self, rng: &mut impl CryptoRngCore,
     ) -> Result<(Self::SharedSecretKey, Self::CipherText), &'static str>;
+
+
+    /// Generates a shared secret and ciphertext from an encapsulation key specific to this security parameter set. <br>
+    /// This function utilizes a provided **seed** (rather than a random number generator) and is intended to operate in constant
+    /// time.
+    /// # Errors
+    /// Returns an error when the random number generator fails or an internal error condition arises.
+    /// # Examples
+    /// ```rust
+    /// # use std::error::Error;
+    /// # fn main() -> Result<(), Box<dyn Error>> {
+    /// # #[cfg(feature = "ml-kem-512")] {
+    /// use rand_core::OsRng;
+    /// use fips203::ml_kem_512;  // Could also be ml_kem_768 or ml_kem_1024.
+    /// use fips203::traits::{KeyGen, SerDes, Decaps, Encaps};
+    ///
+    /// let (ek1, dk1) = ml_kem_512::KG::try_keygen_with_rng(&mut OsRng)?;  // Party 1 generates both encaps and decaps keys
+    /// let ek1_bytes = ek1.into_bytes();  // Party 1 serializes the encaps key
+    ///
+    /// let ek2_bytes = ek1_bytes;  // Party 1 sends encaps bytes to party 2
+    ///
+    /// let ek2 = ml_kem_512::EncapsKey::try_from_bytes(ek2_bytes)?;  // Party 2 deserializes the encaps key
+    /// let (ssk2, ct2) = ek2.encaps_from_seed(&[1u8; 32]);  // Party 2 generates shared secret and ciphertext
+    /// let ct2_bytes = ct2.into_bytes();  // Party 2 serializes the ciphertext
+    ///
+    /// let ct1_bytes = ct2_bytes;  // Party 2 sends the ciphertext to party 1
+    ///
+    /// let ct1 = ml_kem_512::CipherText::try_from_bytes(ct1_bytes)?;  // Party 1 deserializes the ciphertext
+    /// let ssk1 = dk1.try_decaps(&ct1)?;  // Party 1 runs decaps to generate the shared secret
+    ///
+    /// assert_eq!(ssk1, ssk2);  // Each party has the same shared secret
+    /// # }
+    /// # Ok(())}
+    /// ```
+    fn encaps_from_seed(&self, seed: &[u8; 32]) -> (Self::SharedSecretKey, Self::CipherText) {
+        self.try_encaps_with_rng(&mut DummyRng { data: *seed }).expect("rng will not fail")
+    }
 }
 
+/// Internal RNG implementation for deterministic operations.
+/// This is used by the deterministic signing functions and will be refactored.
+struct DummyRng {
+    data: [u8; 32],
+}
 
-/// The `Decaps` trait uses the decapsulation key and ciphertext to generate the shared secret.
+impl RngCore for DummyRng {
+    fn next_u32(&mut self) -> u32 { unimplemented!() }
+
+    fn next_u64(&mut self) -> u64 { unimplemented!() }
+
+    fn fill_bytes(&mut self, _out: &mut [u8]) { unimplemented!() }
+
+    fn try_fill_bytes(&mut self, out: &mut [u8]) -> Result<(), rand_core::Error> {
+        out.copy_from_slice(&self.data);
+        Ok(())
+    }
+}
+
+impl CryptoRng for DummyRng {}
+
+/// The `Decaps` trait defines methods for recovering the shared secret using
+/// a decapsulation key and ciphertext.
 pub trait Decaps {
-    /// Ciphertext struct
+    /// The ciphertext type received from the encapsulating party
     type CipherText;
-    /// Shared secret struct
+    /// The shared secret key type generated during decapsulation
     type SharedSecretKey;
 
 
     /// Generates a shared secret from a decapsulation key and ciphertext specific to this security parameter set. <br>
     /// This function is intended to operate in constant-time.
     /// # Errors
-    /// Returns an error when the random number generator fails or an internal error condition arises.
+    /// Returns an error if an internal error condition arises (e.g., an invalid `ct`).
     /// # Examples
     /// ```rust
     /// # use std::error::Error;
@@ -285,10 +353,9 @@ pub trait Decaps {
     fn try_decaps(&self, ct: &Self::CipherText) -> Result<Self::SharedSecretKey, &'static str>;
 }
 
-
-/// Serialization and Deserialization of structs
+/// The `SerDes` trait provides methods for serializing and deserializing cryptographic objects.
 pub trait SerDes {
-    /// Correctly sized byte array for struct
+    /// The fixed-size byte array type used for serialization
     type ByteArray;
 
 
